@@ -59,12 +59,12 @@ void read_parms()
   if ((fp = sfopen(pparfile, "r")) != (FILE *)NULL) {
 	readpars(fp, 0);
 	fclose(fp);
-
-        /* fmg - set colors from readin values (Jcolor Xlates name to #) */
-        mfcolor = Jcolor(P_MFG); mbcolor = Jcolor(P_MBG);
-        tfcolor = Jcolor(P_TFG); tbcolor = Jcolor(P_TBG);
-        sfcolor = Jcolor(P_SFG); sbcolor = Jcolor(P_SBG);
   }
+
+  /* fmg - set colors from readin values (Jcolor Xlates name to #) */
+  mfcolor = Jcolor(P_MFG); mbcolor = Jcolor(P_MBG);
+  tfcolor = Jcolor(P_TFG); tbcolor = Jcolor(P_TBG);
+  sfcolor = Jcolor(P_SFG); sbcolor = Jcolor(P_SBG);
  
 #if _HAVE_MACROS
   /* fmg - Read personal macros */
@@ -592,12 +592,13 @@ static void doscrkeyb()
   int clr = 1;
   int tmp_c;    /* fmg - need it to color keep in sanity checks */
   char buf[16];
-  int miny = 5, maxy = 17;
+  int miny = 4, 
+  maxy = 17;
   int old_stat = P_STATLINE[0];
 #if _HAVE_MACROS
   FILE	*fp;
 
-  miny = 4;
+  miny = 3;
   maxy = 19;
 #endif
 
@@ -616,12 +617,15 @@ static void doscrkeyb()
   wprintf(w, " H - Background Color (term): %s\n", J_col[tbcolor]);
   wprintf(w, " I - Foreground Color (stat): %s\n", J_col[sfcolor]);
   wprintf(w, " J - Background Color (stat): %s\n", J_col[sbcolor]);
+  
+  /* MARK updated 02/17/95 - Configurable history buffer size */
+  wprintf(w, " K - History Buffer Size    : %s\n", P_HISTSIZE);
 
 #if _HAVE_MACROS
   /* fmg - macros support */
-  wprintf(w, " K - Macros file            : %s\n", P_MACROS);
-  wprintf(w, " L - Edit Macros\n");
-  wprintf(w, " M - Macros enabled         : %s\n", P_MACENAB);
+  wprintf(w, " L - Macros file            : %s\n", P_MACROS);
+  wprintf(w, " M - Edit Macros\n");
+  wprintf(w, " N - Macros enabled         : %s\n", P_MACENAB);
 #endif
 
   wredraw(w, 1);
@@ -672,6 +676,21 @@ static void doscrkeyb()
                  /* fmg - I'll let them change sfcolor=sbcolor because it's just
                           another way of turning "off" the status line... */
 
+			/* MARK updated 02/17/95, Warn user to restart */
+			/* minicom if they changed history buffer size */
+			if (atoi(P_HISTSIZE) != num_hist_lines) {
+				w1 = wopen(14, 9, 70, 15, BSINGLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+				wtitle(w1, TMID, "History Buffer Size");
+				wputs(w1, "\n"
+					"  You have changed the history buffer size.\n"
+					"  You will need to save the configuration file and\n"
+					"  restart minicom for the change to take effect.\n\n"
+					"  Hit a key to Continue... ");
+				wredraw(w1, 1);
+				c = getch();
+				wclose(w1, 1);
+			}
+
   			wclose(w, 1);
 			/* If status line enabled/disabled resize screen. */
 			if (P_STATLINE[0] != old_stat)
@@ -765,6 +784,7 @@ static void doscrkeyb()
                         psets(P_TFG, J_col[tfcolor]);
                         wlocate(w, 30, 7);
                         wprintf(w, "%s   ", J_col[tfcolor]);
+			if (us) vt_pinit(us, tfcolor, tbcolor);
                         break;
                 case 'H': /* fmg - letters cycle colors */
                         if (tbcolor == WHITE)
@@ -774,6 +794,7 @@ static void doscrkeyb()
                         psets(P_TBG, J_col[tbcolor]);
                         wlocate(w, 30, 8);
                         wprintf(w, "%s   ", J_col[tbcolor]);
+			if (us) vt_pinit(us, tfcolor, tbcolor);
                         break;
                 case 'I': /* fmg - letters cycle colors & redraw stat line */
                         if (sfcolor == WHITE)
@@ -815,9 +836,28 @@ static void doscrkeyb()
                         wlocate(w, 30, 10);
                         wprintf(w, "%s   ", J_col[sbcolor]);
                         break;
+		case 'K': /* MARK updated 02/17/95 - Config history size */
+#if HISTORY
+                        pgets(w, 30, 11, P_HISTSIZE, 5, 5);
+                        
+                        /* In case gibberish or a value was out of bounds, */
+                        /* limit history buffer size between 0 to 5000 lines */
+                        /* 5000 line history at 80 columns consumes about */
+                        /* 800 kilobytes including chars and attrs bytes! */
+                        if (atoi(P_HISTSIZE) <= 0) 
+                        	strcpy(P_HISTSIZE,"0");
+                        else if (atoi(P_HISTSIZE) >= 5000)
+                        	strcpy(P_HISTSIZE,"5000");
+	                        
+                        wlocate(w, 30, 11);
+                        wprintf(w, "%s     ", P_HISTSIZE);
+#else
+			werror("This system does not support history");
+#endif
+			break;
 #if _HAVE_MACROS
-                case 'K': /* fmg - get local macros storage file */
-                        pgets(w, 30, 11, P_MACROS, 64, 64);
+                case 'L': /* fmg - get local macros storage file */
+                        pgets(w, 30, 12, P_MACROS, 64, 64);
 
 			/* Try to open the file to read it in. */
 			fp = sfopen(pfix_home(P_MACROS), "r+");
@@ -840,12 +880,12 @@ static void doscrkeyb()
 			readmacs(fp, 0);
 			fclose(fp);
                         break;
-                case 'L': /* fmg - Bring up macro editing window */
+                case 'M': /* fmg - Bring up macro editing window */
                         domacros();
                         break;
-		case 'M':
+		case 'N':
 			psets(P_MACENAB, yesno(P_MACENAB[0] == 'N'));
-			wlocate(w, 30, 13);
+			wlocate(w, 30, 14);
 			wprintf(w, "%s", P_MACENAB);
 			break;
 #endif
